==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/item/BaubleBoxItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item;

import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1277;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1735;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_3222;
import net.minecraft.class_3908;
import net.minecraft.class_5328;
import net.minecraft.class_5536;
import net.minecraft.class_5630;
import net.minecraft.world.*;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.client.gui.box.BaubleBoxContainer;
import vazkii.botania.common.handler.EquipmentHandler;
import vazkii.botania.common.helper.InventoryHelper;
import vazkii.botania.xplat.XplatAbstractions;

import java.util.stream.IntStream;
import java.util.stream.Stream;

public class BaubleBoxItem extends class_1792 {
	public static final int SIZE = 24;

	public BaubleBoxItem(class_1793 props) {
		super(props);
	}

	public static class_1277 getInventory(class_1799 stack) {
		return new ItemBackedInventory(stack, SIZE) {
			@Override
			public boolean method_5437(int index, @NotNull class_1799 stack) {
				return EquipmentHandler.instance.isAccessory(stack);
			}
		};
	}

	@NotNull
	@Override
	public class_1271<class_1799> method_7836(class_1937 world, class_1657 player, @NotNull class_1268 hand) {
		if (!world.field_9236) {
			class_1799 stack = player.method_5998(hand);
			XplatAbstractions.INSTANCE.openMenu((class_3222) player, new class_3908() {
				@Override
				public class_2561 method_5476() {
					return stack.method_7964();
				}

				@Override
				public class_1703 createMenu(int syncId, class_1661 inv, class_1657 player) {
					return new BaubleBoxContainer(syncId, inv, stack);
				}
			}, buf -> buf.writeBoolean(hand == class_1268.field_5808));
		}
		return class_1271.method_29237(player.method_5998(hand), world.method_8608());
	}

	@Override
	public void method_33261(@NotNull class_1542 entity) {
		var container = getInventory(entity.method_6983());
		var stream = IntStream.range(0, container.method_5439())
				.mapToObj(container::method_5438)
				.filter(s -> !s.method_7960());
		class_5328.method_33263(entity, stream);
		container.method_5448();
	}

	@Override
	public boolean method_31565(
			@NotNull class_1799 box, @NotNull class_1735 slot,
			@NotNull class_5536 clickAction, @NotNull class_1657 player) {
		return InventoryHelper.overrideStackedOnOther(
				BaubleBoxItem::getInventory,
				player.field_7512 instanceof BaubleBoxContainer,
				box, slot, clickAction, player);
	}

	@Override
	public boolean method_31566(
			@NotNull class_1799 box, @NotNull class_1799 toInsert,
			@NotNull class_1735 slot, @NotNull class_5536 clickAction,
			@NotNull class_1657 player, @NotNull class_5630 cursorAccess) {
		return InventoryHelper.overrideOtherStackedOnMe(
				BaubleBoxItem::getInventory,
				player.field_7512 instanceof BaubleBoxContainer,
				box, toInsert, clickAction, cursorAccess);
	}
}

==> Botania-1.20.1-449-FABRIC-20250801.173638-44-sources.jar: vazkii/botania/common/item/BaubleBoxItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item;

import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1277;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1735;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_3222;
import net.minecraft.class_3908;
import net.minecraft.class_5328;
import net.minecraft.class_5536;
import net.minecraft.class_5630;
import net.minecraft.world.*;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.client.gui.box.BaubleBoxContainer;
import vazkii.botania.common.handler.EquipmentHandler;
import vazkii.botania.common.helper.InventoryHelper;
import vazkii.botania.common.helper.ItemNBTHelper;
import vazkii.botania.xplat.XplatAbstractions;

import java.util.stream.IntStream;
import java.util.stream.Stream;

public class BaubleBoxItem extends class_1792 {
	public static final int SIZE = 24;
	public static final String TAG_OPEN = "open";

	public BaubleBoxItem(class_1793 props) {
		super(props);
	}

	public static class_1277 getInventory(class_1799 stack) {
		return new ItemBackedInventory(stack, SIZE) {
			@Override
			public boolean method_5437(int index, @NotNull class_1799 stack) {
				return EquipmentHandler.instance.isAccessory(stack);
			}
		};
	}

	@NotNull
	@Override
	public class_1271<class_1799> method_7836(class_1937 world, class_1657 player, @NotNull class_1268 hand) {
		if (!world.field_9236) {
			class_1799 stack = player.method_5998(hand);
			ItemNBTHelper.setBoolean(stack, TAG_OPEN, true);
			XplatAbstractions.INSTANCE.openMenu((class_3222) player, new class_3908() {
				@Override
				public class_2561 method_5476() {
					return stack.method_7964();
				}

				@Override
				public class_1703 createMenu(int syncId, class_1661 inv, class_1657 player) {
					return new BaubleBoxContainer(syncId, inv, stack);
				}
			}, buf -> buf.writeBoolean(hand == class_1268.field_5808));
		}
		return class_1271.method_29237(player.method_5998(hand), world.method_8608());
	}

	@Override
	public void method_33261(@NotNull class_1542 entity) {
		var container = getInventory(entity.method_6983());
		var stream = IntStream.range(0, container.method_5439())
				.mapToObj(container::method_5438)
				.filter(s -> !s.method_7960());
		class_5328.method_33263(entity, stream);
		container.method_5448();
	}

	@Override
	public boolean method_31565(
			@NotNull class_1799 box, @NotNull class_1735 slot,
			@NotNull class_5536 clickAction, @NotNull class_1657 player) {
		return InventoryHelper.overrideStackedOnOther(
				BaubleBoxItem::getInventory,
				player.field_7512 instanceof BaubleBoxContainer,
				box, slot, clickAction, player);
	}

	@Override
	public boolean method_31566(
			@NotNull class_1799 box, @NotNull class_1799 toInsert,
			@NotNull class_1735 slot, @NotNull class_5536 clickAction,
			@NotNull class_1657 player, @NotNull class_5630 cursorAccess) {
		return InventoryHelper.overrideOtherStackedOnMe(
				BaubleBoxItem::getInventory,
				player.field_7512 instanceof BaubleBoxContainer,
				box, toInsert, clickAction, cursorAccess);
	}
}
